Crate kcr_workspace_devfile_io

Crate kcr_workspace_devfile_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the workspace.devfile.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

workspace.devfile.io/v1alpha1

  • DevWorkspace
  • DevWorkspaceTemplate

workspace.devfile.io/v1alpha2

  • DevWorkspace
  • DevWorkspaceTemplate

Modules

v1alpha1
v1alpha2